@@ -8,9 +8,9 @@ __title__ = 'pyz3r'
 __author__ = 'Thomas Prescott'
 __license__ = 'Apache 2.0'
 __copyright__ = 'Copyright 2018-2019 Thomas Prescott'
-__version__ = '4.6.2'
+__version__ = '5.2.7'
 
 from .alttpr import alttpr
 from .sm import sm
-from .smz3 import smz3
-from . import rom, mystery, customizer, patch
+from .smvaria import SuperMetroidVaria
+from . import mystery, customizer, rom, patch
\ No newline at end of file
